@@ -1,7 +1,7 @@
 """``kedro.framework.cli`` implements commands available from Kedro's CLI.
 """
 
-from .cli import get_project_context, main
+from .cli import main
 from .utils import command_with_verbosity, load_entry_points
 
-__all__ = ["get_project_context", "main", "command_with_verbosity", "load_entry_points"]
+__all__ = ["main", "command_with_verbosity", "load_entry_points"]
