@@ -28,42 +28,28 @@ from kedro.framework.session.store import BaseSessionStore
 from kedro.io.core import generate_timestamp
 from kedro.runner import AbstractRunner, SequentialRunner
 
-_active_session = None
-
-
-def _activate_session(session: "KedroSession", force: bool = False) -> None:
-    global _active_session
-
-    if _active_session and not force and session is not _active_session:
-        raise RuntimeError(
-            "Cannot activate the session as another active session already exists."
-        )
-
-    _active_session = session
-
-
-def _deactivate_session() -> None:
-    global _active_session
-    _active_session = None
-
 
 def _describe_git(project_path: Path) -> Dict[str, Dict[str, Any]]:
     project_path = str(project_path)
-
     try:
         res = subprocess.check_output(
-            ["git", "rev-parse", "--short", "HEAD"], cwd=project_path
+            ["git", "rev-parse", "--short", "HEAD"],
+            cwd=project_path,
+            stderr=subprocess.STDOUT,
         )
+        git_data = {"commit_sha": res.decode().strip()}  # type: Dict[str, Any]
+        git_status_res = subprocess.check_output(
+            ["git", "status", "--short"],
+            cwd=project_path,
+            stderr=subprocess.STDOUT,
+        )
+        git_data["dirty"] = bool(git_status_res.decode().strip())
+
     # `subprocess.check_output()` raises `NotADirectoryError` on Windows
     except (subprocess.CalledProcessError, FileNotFoundError, NotADirectoryError):
         logging.getLogger(__name__).warning("Unable to git describe %s", project_path)
         return {}
 
-    git_data = {"commit_sha": res.decode().strip()}  # type: Dict[str, Any]
-
-    res = subprocess.check_output(["git", "status", "--short"], cwd=project_path)
-    git_data["dirty"] = bool(res.decode().strip())
-
     return {"git": git_data}
 
 
@@ -256,6 +242,10 @@ class KedroSession:
             extra_params=extra_params,
             hook_manager=self._hook_manager,
         )
+        self._hook_manager.hook.after_context_created(  # pylint: disable=no-member
+            context=context
+        )
+
         return context
 
     def _get_config_loader(self) -> ConfigLoader:
@@ -278,12 +268,7 @@ class KedroSession:
         if self.save_on_close:
             self._store.save()
 
-        if _active_session is self:
-            _deactivate_session()
-
     def __enter__(self):
-        if _active_session is not self:
-            _activate_session(self)
         return self
 
     def __exit__(self, exc_type, exc_value, tb_):
@@ -387,6 +372,7 @@ class KedroSession:
             "load_versions": load_versions,
             "extra_params": extra_params,
             "pipeline_name": pipeline_name,
+            "runner": getattr(runner, "__name__", str(runner)),
         }
 
         catalog = context._get_catalog(
@@ -395,8 +381,8 @@ class KedroSession:
         )
 
         # Run the runner
-        runner = runner or SequentialRunner()
         hook_manager = self._hook_manager
+        runner = runner or SequentialRunner()
         hook_manager.hook.before_pipeline_run(  # pylint: disable=no-member
             run_params=record_data, pipeline=filtered_pipeline, catalog=catalog
         )
