@@ -438,7 +438,7 @@ def _load_obj(class_path: str) -> Optional[object]:
                 f"{exc} Please see the documentation on how to "
                 f"install relevant dependencies for {class_path}:\n"
                 f"https://kedro.readthedocs.io/en/stable/"
-                f"04_kedro_project_setup/01_dependencies.html"
+                f"kedro_project_setup/dependencies.html"
             ) from exc
         return None
 
@@ -521,7 +521,7 @@ class AbstractVersionedDataSet(AbstractDataSet, abc.ABC):
         self._exists_function = exists_function or _local_exists
         self._glob_function = glob_function or iglob
         # 1 entry for load version, 1 for save version
-        self._version_cache = Cache(maxsize=2)
+        self._version_cache = Cache(maxsize=2)  # type: Cache
 
     # 'key' is set to prevent cache key overlapping for load and save:
     # https://cachetools.readthedocs.io/en/stable/#cachetools.cachedmethod
